@@ -1,4 +1,4 @@
-from keras_bcr import BatchCorrRegulizer
+from keras_bcr import BatchCorrRegularizer
 import tensorflow as tf
 
 
@@ -8,24 +8,24 @@ def build_resnet_block(inputs, units=64, activation="gelu",
     h = tf.keras.layers.Dense(units=units)(inputs)
     h = h = tf.keras.layers.Activation(activation=activation)(h)
     h = tf.keras.layers.Dropout(rate=dropout)(h)
-    h = BatchCorrRegulizer(bcr_rate=bcr_rate)([h, inputs])  # << HERE
+    h = BatchCorrRegularizer(bcr_rate=bcr_rate)([h, inputs])  # << HERE
     outputs = tf.keras.layers.Add()([h, inputs])
     return outputs
 
 
 # An model with 3 ResNet blocks
-def build_model(input_dim):
-    inputs = tf.keras.Input(shape=(input_dim,))
-    h = build_resnet_block(inputs, units=input_dim)
-    h = build_resnet_block(h, units=input_dim)
-    outputs = build_resnet_block(h, units=input_dim)
+def build_model(input_dims):
+    inputs = tf.keras.Input(shape=input_dims)
+    h = build_resnet_block(inputs, units=input_dims[-1])
+    h = build_resnet_block(h, units=input_dims[-1])
+    outputs = build_resnet_block(h, units=input_dims[-1])
     model = tf.keras.Model(inputs=inputs, outputs=outputs)
     return model
 
 
 def test1():
     INPUT_DIM = 64
-    model = build_model(input_dim=INPUT_DIM)
+    model = build_model(input_dims=[INPUT_DIM])
     model.compile(
         optimizer=tf.keras.optimizers.Adam(),
         loss="mean_squared_error")
@@ -35,4 +35,20 @@ def test1():
     y_train = tf.random.normal([BATCH_SZ])
 
     history = model.fit(X_train, y_train, verbose=1, epochs=2)
-    assert "batch_corr_regulizer" in history.history.keys()
+    assert "batch_corr_regularizer" in history.history.keys()
+
+
+def test2():
+    EMBED_DIM = 64
+    SEQLEN = 32
+    model = build_model(input_dims=[SEQLEN, EMBED_DIM])
+    model.compile(
+        optimizer=tf.keras.optimizers.Adam(),
+        loss="mean_squared_error")
+
+    BATCH_SZ = 128
+    X_train = tf.random.normal([BATCH_SZ, SEQLEN, EMBED_DIM])
+    y_train = tf.random.normal([BATCH_SZ, SEQLEN, EMBED_DIM])
+
+    history = model.fit(X_train, y_train, verbose=1, epochs=2)
+    assert "batch_corr_regularizer" in history.history.keys()
